summaryrefslogtreecommitdiff
path: root/gdb/frame.h
diff options
context:
space:
mode:
authorAndrew Cagney <cagney@redhat.com>2003-04-06 18:36:23 +0000
committerAndrew Cagney <cagney@redhat.com>2003-04-06 18:36:23 +0000
commite876204833fec2919e280a7e2d57b25067865836 (patch)
tree25df6a1d57db90638ae609e719fde7b60cc524fc /gdb/frame.h
parent8e748fba6209af7b89fa12b63d593768035f57db (diff)
downloadgdb-e876204833fec2919e280a7e2d57b25067865836.tar.gz
2003-04-06 Andrew Cagney <cagney@redhat.com>
* frame.h (legacy_frame_chain_valid): Rename frame_chain_valid. Update comment. * frame.c (legacy_saved_regs_this_id): Update. (legacy_get_prev_frame): Update. * xstormy16-tdep.c: Update comment. * sparc-tdep.c (sparc_frame_chain): Update comment. * blockframe.c (legacy_frame_chain_valid): Update.
Diffstat (limited to 'gdb/frame.h')
-rw-r--r--gdb/frame.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/gdb/frame.h b/gdb/frame.h
index f928b9c11ba..e352ebca05b 100644
--- a/gdb/frame.h
+++ b/gdb/frame.h
@@ -455,10 +455,14 @@ enum print_what
extern void *frame_obstack_zalloc (unsigned long size);
#define FRAME_OBSTACK_ZALLOC(TYPE) ((TYPE *) frame_obstack_zalloc (sizeof (TYPE)))
-/* If DEPRECATED_FRAME_CHAIN_VALID returns zero it means that the
- given frame is the outermost one and has no caller. */
-
-extern int frame_chain_valid (CORE_ADDR, struct frame_info *);
+/* If legacy_frame_chain_valid() returns zero it means that the given
+ frame is the outermost one and has no caller.
+
+ This method has been superseeded by the per-architecture
+ frame_unwind_pc() (returns 0 to indicate an invalid return address)
+ and per-frame this_id() (returns a NULL frame ID to indicate an
+ invalid frame). */
+extern int legacy_frame_chain_valid (CORE_ADDR, struct frame_info *);
extern void generic_save_dummy_frame_tos (CORE_ADDR sp);